==> cbra-0.19.1.tar.gz: cbra-0.19.1/cbra/ext/google/debugtransport.py <==
"""Declares :class:`DebugTransport`."""
import asyncio
import base64
import datetime
import os

import aorta
from httpx import AsyncClient

import cbra
from .models import MessagePublished


class DebugTransport(aorta.transport.ITransport):
    """A :class:`aorta.transport.ITransport` implementation that sends
    messages to the ASGI application provided to the constructor.
    """

    def __init__(self, app: cbra.Application, base_url: str, path: str):
        self.app = app
        self.base_url = base_url
        self.path = path

    async def send(self, objects: list):
        """Construct a :class:`~cbra.ext.google.models.MessagePublished`
        instance and send it to the Eventarc endpoint.
        """
        futures = []
        async with AsyncClient(app=self.app, base_url=self.base_url) as client:
            for obj in objects:
                message = MessagePublished(**{
                    'subscription': "projects/abcdef/subscriptions/abcdef",
                    'message': {
                        'messageId': bytes.hex(os.urandom(16)),
                        'publishTime': datetime.datetime.utcnow().isoformat(),
                        'attributes': {},
                        'data': base64.b64encode(bytes(obj))
                    }
                })
                futures.append(self._send(client, message))

            await asyncio.gather(*futures)

    async def _send(self, client: AsyncClient, message: MessagePublished):
        response = await client.post(
            url=self.path,
            data=message.json(by_alias=True),
            headers={
                'Accept': "application/json",
                'Content-Type': "application/json"
            }
        )
        if response.status_code != 202:
            raise Exception(response.text, response.status_code, response.url)

==> cbra-0.50.0.tar.gz: cbra-0.50.0/cbra/ext/google/debugtransport.py <==
"""Declares :class:`DebugTransport`."""
import asyncio
import base64
import datetime
import os

import aorta
from httpx import AsyncClient

import cbra
from .models import MessagePublished


class DebugTransport(aorta.transport.ITransport): # pragma: no cover
    """A :class:`aorta.transport.ITransport` implementation that sends
    messages to the ASGI application provided to the constructor.
    """

    def __init__(self, app: cbra.Application, base_url: str, path: str):
        self.app = app
        self.base_url = base_url
        self.path = path

    async def send(self, objects: list):
        """Construct a :class:`~cbra.ext.google.models.MessagePublished`
        instance and send it to the Eventarc endpoint.
        """
        futures = []
        async with AsyncClient(app=self.app, base_url=self.base_url) as client:
            for obj in objects:
                message = MessagePublished(**{
                    'subscription': "projects/abcdef/subscriptions/abcdef",
                    'message': {
                        'messageId': bytes.hex(os.urandom(16)),
                        'publishTime': datetime.datetime.utcnow().isoformat(),
                        'attributes': {},
                        'data': base64.b64encode(bytes(obj))
                    }
                })
                futures.append(self._send(client, message))

            await asyncio.gather(*futures)

    async def _send(self, client: AsyncClient, message: MessagePublished):
        response = await client.post(
            url=self.path,
            data=message.json(by_alias=True),
            headers={
                'Accept': "application/json",
                'Content-Type': "application/json"
            }
        )
        if response.status_code != 202:
            raise Exception(response.text, response.status_code, response.url)
